Class: Inquirex::TTY::Commands::Version
- Inherits:
-
Dry::CLI::Command
- Object
- Dry::CLI::Command
- Inquirex::TTY::Commands::Version
- Defined in:
- lib/inquirex/tty/commands/version.rb
Overview
Prints inquirex-tty and inquirex gem versions to stdout.
Instance Method Summary collapse
-
#call ⇒ void
Prints the version of this gem and of the core inquirex gem.
Instance Method Details
#call ⇒ void
This method returns an undefined value.
Prints the version of this gem and of the core inquirex gem. Any CLI options are accepted and ignored.
14 15 16 17 |
# File 'lib/inquirex/tty/commands/version.rb', line 14 def call(**) puts "inquirex-tty #{Inquirex::TTY::VERSION}" puts "inquirex #{Inquirex::VERSION}" end |